BulkString

Struct BulkString 

pub struct BulkString(/* private fields */);
A bulk string.

In Redis terminology a string is a byte-array, so this is stored as a vector of u8s to allow clients to interpret the bytes as appropriate.

Implementations

Source

impl BulkString

pub fn from_static(data: &'static str) -> Self

Create request from static str

pub fn from_bstatic(data: &'static [u8]) -> Self

Create request from static str